@@ -94,14 +94,6 @@ readCohortSet <- function(path) {
   return(cohortsToCreate)
 }
 
-#' `r lifecycle::badge("deprecated")`
-#' @export
-#' @rdname readCohortSet
-read_cohort_set <- function(path) {
-  lifecycle::deprecate_soft("1.7.0", "read_cohort_set()", "readCohortSet()")
-  readCohortSet(path)
-}
-
 #' Generate a cohort set on a cdm object
 #'
 #' @description
@@ -137,8 +129,8 @@ read_cohort_set <- function(path) {
 #' @param name Name of the cohort table to be created. This will also be used
 #' as a prefix for the cohort attribute tables. This must be a lowercase character string
 #' that starts with a letter and only contains letters, numbers, and underscores.
-#' @param cohort_set,cohortSet Can be a cohortSet object created with `readCohortSet()`
-#' @param compute_attrition,computeAttrition Should attrition be computed? TRUE (default) or FALSE
+#' @param cohortSet A cohortSet dataframe created with `readCohortSet()`
+#' @param computeAttrition Should attrition be computed? TRUE (default) or FALSE
 #' @param overwrite Should the cohort table be overwritten if it already
 #' exists? TRUE (default) or FALSE
 #' @export
@@ -172,26 +164,6 @@ generateCohortSet <- function(cdm,
     rlang::abort("`cohortSet` must be a dataframe from the output of `readCohortSet()`.")
   }
 
-  # if (!is.data.frame(cohortSet)) {
-  #   if (!is.list(cohortSet)) {
-  #     rlang::abort("cohortSet must be a dataframe or a named list of Capr cohort definitions")
-  #   }
-  #
-  #   checkmate::assertList(cohortSet,
-  #                         types = "Cohort",
-  #                         min.len = 1,
-  #                         names = "strict",
-  #                         any.missing = FALSE)
-  #
-  #   cohortSet <- dplyr::tibble(
-  #     cohort_definition_id = seq_along(cohortSet),
-  #     cohort_name = names(cohortSet),
-  #     cohort = purrr::map(cohortSet, ~jsonlite::fromJSON(generics::compile(.), simplifyVector = FALSE)),
-  #     json = purrr::map_chr(cohortSet, generics::compile)
-  #   )
-  #   class(cohortSet) <- c("CohortSet", class(cohortSet))
-  # }
-
   checkmate::assertDataFrame(cohortSet, min.rows = 1, col.names = "named")
   stopifnot(all(c("cohort_definition_id", "cohort_name", "cohort", "json") %in% names(cohortSet)))
 
@@ -510,238 +482,6 @@ generateCohortSet <- function(cdm,
   return(cdm)
 }
 
-#' `r lifecycle::badge("deprecated")`
-#' @rdname generateCohortSet
-#' @export
-generate_cohort_set <- function(cdm,
-                                cohort_set,
-                                name = "cohort",
-                                compute_attrition = TRUE,
-                                overwrite = TRUE) {
-  lifecycle::deprecate_soft("1.7.0", "generate_cohort_set()", "generateCohortSet()")
-  generateCohortSet(cdm = cdm,
-                    cohortSet = cohort_set,
-                    name = name,
-                    computeAttrition = compute_attrition,
-                    overwrite = overwrite)
-}
-
-
-#' Constructor for cohort_table objects
-#'
-#' `r lifecycle::badge("deprecated")`
-#'
-#' Please use `omopgenerics::newCohortTable()` instead.
-#'
-#' This constructor function is to be used by analytic package developers to
-#' create `cohort_table` objects.
-#'
-#' @details
-#' A `cohort_table` is a set of person-time from an OMOP CDM database.
-#' A `cohort_table` can be represented by a table with three columns:
-#' subject_id, cohort_start_date, cohort_end_date. Subject_id is the same as
-#' person_id in the OMOP CDM. A `cohort_table` is a collection of one
-#' or more `cohort_table` and can be represented as a table with four
-#' columns: cohort_definition_id, subject_id, cohort_start_date,
-#' cohort_end_date.
-#'
-#' This constructor function defines the `cohort_table` object in R.
-#'
-#' The object is an extension of a `tbl_sql` object defined in dplyr. This is
-#' a lazy database query that points to a cohort table in the database with
-#' at least the columns cohort_definition_id, subject_id, cohort_start_date,
-#' cohort_end_date. The table could optionally have more columns as well.
-#'
-#' In addition the `cohort_table` object has three optional attributes.
-#' These are: cohort_set, cohort_attrition, cohort_count.
-#' Each of these attributes is also a lazy SQL query (`tbl_sql`) that points
-#' to a table in a database and is described below.
-#'
-#' ## cohort_set
-#'
-#' cohort_set is a table with one row per cohort_definition_id. The first
-#' two columns of the cohort_set table are: cohort_definition_id, and
-#' cohort_name. Additional columns can be added. The cohort_set table is meant
-#' to store metadata about the cohort definition. Since this table is required it
-#' will be created if it it is not supplied.
-#'
-#' ## cohort_attrition
-#'
-#' cohort_attrition is an optional table that stores attrition information
-#' recorded during the cohort generation process such as how many persons were
-#' dropped at each step of inclusion rule application. The first column of this
-#' table should be `cohort_definition_id` but all other columns currently
-#' have no constraints.
-#'
-#' ## cohort_count
-#'
-#' cohort_count is a option attribute table that records the number of records
-#' and the number of unique persons in each cohort in a `cohort_table`.
-#' It is derived metadata that can be re-derived as long as cohort_set,
-#' the complete list of cohorts in the set, is available. Column names of
-#' cohort_count are: cohort_definition_id, number_records,
-#' number_subjects. This table is required for cohort_table objects and
-#' will be created if not supplied.
-#'
-#' @param cohort_ref,cohortRef A `tbl_sql` object that points to a remote cohort table
-#' with the following first four columns: cohort_definition_id,
-#' subject_id, cohort_start_date, cohort_end_date. Additional columns are
-#' optional.
-#' @param cohort_set_ref,cohortSetRef A `tbl_sql` object that points to a remote table
-#' with the following first two columns: cohort_definition_id, cohort_name.
-#' Additional columns are optional. cohort_definition_id should be a primary
-#' key on this table and uniquely identify rows.
-#' @param cohort_attrition_ref,cohortAttritionRef A `tbl_sql` object that points to an attrition
-#' table in a remote database with the first column being cohort_definition_id.
-#' @param cohort_count_ref,cohortCountRef A `tbl_sql` object that points to a cohort_count
-#' table in a remote database with columns cohort_definition_id, cohort_entries,
-#' cohort_subjects.
-#' @param overwrite Should tables be overwritten if they already exist? TRUE or FALSE (default)
-#'
-#' @return A `cohort_table` object that is a `tbl_sql` reference
-#' to a cohort table in the write_schema of an OMOP CDM
-#' @export
-#'
-#' @include reexports-omopgenerics.R
-#'
-#' @examples
-#' \dontrun{
-#'  # This function is for developers who are creating cohort_table
-#'  # objects in their packages. The function should accept a cdm_reference
-#'  # object as the first argument and return a cdm_reference object with the
-#'  # cohort table added. The second argument should be `name` which will be
-#'  # the prefix for the database tables, the name of the cohort table in the
-#'  # database and the name of the cohort table in the cdm object.
-#'  # Other optional arguments can be added after the first two.
-#'
-#'  generateCustomCohort <- function(cdm, name, ...) {
-#'
-#'    # accept a cdm_reference object as input
-#'    checkmate::assertClass(cdm, "cdm_reference")
-#'    con <- attr(cdm, "dbcon")
-#'
-#'    # Create the tables in the database however you like
-#'    # All the tables should be prefixed with `name`
-#'    # The cohort table should be called `name` in the database
-#'
-#'    # Create the dplyr table references
-#'    cohort_ref <- dplyr::tbl(con, name)
-#'    cohort_set <- dplyr::tbl(con, paste0(name, "_set"))
-#'    cohort_attrition_ref <- dplyr::tbl(con, paste0(name, "_attrition"))
-#'    cohort_count_ref <- dplyr::tbl(con, paste0(name, "_count"))
-#'
-#'    # add to the cdm
-#'    cdm[[name]] <- cohort_ref
-#'
-#'    # create the generated cohort set object using the constructor
-#'    cdm[[name]] <- newGeneratedCohortSet(
-#'       cdm[[name]],
-#'       cohortSetRef = cohort_set_ref,
-#'       cohortAttritionRef = cohort_attrition_ref,
-#'       cohortCountRef = cohort_count_ref)
-#'
-#'    return(cdm)
-#'  }
-#' }
-new_generated_cohort_set <- function(cohort_ref,
-                                     cohort_set_ref = NULL,
-                                     cohort_attrition_ref = NULL,
-                                     cohort_count_ref = NULL,
-                                     overwrite) {
-  lifecycle::deprecate_warn(
-    when = "1.3",
-    what = "new_generated_cohort_set()",
-    with = "newCohortTable()"
-  )
-
-
-  omopgenerics::newCohortTable(
-    table = cohort_ref,
-    cohortSetRef = cohort_set_ref,
-    cohortAttritionRef = cohort_attrition_ref
-  )
-}
-
-
-#' @rdname new_generated_cohort_set
-#' @export
-newGeneratedCohortSet <- function(cohortRef,
-                                  cohortSetRef = NULL,
-                                  cohortAttritionRef = NULL,
-                                  cohortCountRef = NULL,
-                                  overwrite) {
-  new_generated_cohort_set(
-    cohort_ref = cohortRef,
-    cohort_set_ref = cohortSetRef,
-    cohort_attrition_ref = cohortAttritionRef,
-    cohort_count_ref = cohortCountRef
-  )
-}
-
-
-#' Get attrition table from a cohort_table object
-#'
-#' @param x A cohort_table object
-#'
-#' @export
-cohortAttrition <- function(x) {
-  lifecycle::deprecate_warn("1.3", "cohortAttrition()", "attrition()")
-  omopgenerics::attrition(x)
-}
-
-#' `r lifecycle::badge("deprecated")`
-#' @rdname cohortAttrition
-#' @export
-cohort_attrition <- function(x) {
-  lifecycle::deprecate_warn("1.3", "cohort_attrition()", "attrition()")
-  omopgenerics::attrition(x)
-}
-
-#' Get cohort settings from a cohort_table object
-#'
-#' @param x A cohort_table object
-#'
-#' @export
-cohortSet <- function(x) {
-  lifecycle::deprecate_warn("1.3", "cohortSet()", "settings()")
-  omopgenerics::settings(x)
-}
-
-#' `r lifecycle::badge("deprecated")`
-#' @rdname cohortSet
-#' @export
-cohort_set <- function(x) {
-  lifecycle::deprecate_warn("1.3", "cohort_set()", "settings()")
-  omopgenerics::settings(x)
-}
-
-#' Get cohort counts from a generated_cohort_set object.
-#'
-#' `r lifecycle::badge("deprecated")`
-#'
-#' @param cohort A generated_cohort_set object.
-#'
-#' @return A table with the counts.
-#' @rdname cohort_count
-#' @export
-#'
-#' @examples
-#' \dontrun{
-#' library(CDMConnector)
-#' library(dplyr)
-#'
-#' con <- DBI::dbConnect(duckdb::duckdb(), eunomiaDir())
-#' cdm <- cdmFromCon(con = con, cdmSchema = "main", writeSchema = "main")
-#' cdm <- generateConceptCohortSet(
-#'   cdm = cdm, conceptSet = list(pharyngitis = 4112343), name = "new_cohort"
-#' )
-#' cohortCount(cdm$new_cohort)
-#' }
-cohort_count <- function(cohort){
-  lifecycle::deprecate_soft("1.7.0", "cohort_count()", "cohortCount()")
-  omopgenerics::cohortCount(cohort)
-}
-
 # Compute the attrition for a set of cohorts (internal function)
 #
 # @description This function computes the attrition for a set of cohorts. It
@@ -899,6 +639,33 @@ computeAttritionTable <- function(cdm,
       excluded_subjects = as.integer(.data$excluded_subjects)
     )
 
+  # Make sure last row of attrition matches actual record counts in the cohort table
+  # Difference can be due to collapsing of cohort records in the cohort eras Circe step.
+  finalCounts <- dplyr::tbl(con, .inSchema(schema, cohortStem, dbms(con))) %>%
+    dplyr::group_by(.data$cohort_definition_id) %>%
+    dplyr::summarise(n_records = dplyr::n(), n_subjects = dplyr::n_distinct(.data$subject_id)) %>%
+    dplyr::collect()
+
+  lastAttritionRow <- dplyr::slice_max(attrition, n = 1, order_by = .data$reason_id, by = "cohort_definition_id")
+
+  newAttritionRow <- dplyr::inner_join(finalCounts, lastAttritionRow, by = "cohort_definition_id") %>%
+    dplyr::mutate(
+      excluded_records = .data$number_records - .data$n_records,
+      excluded_subjects = .data$number_subjects - .data$n_subjects,
+    ) %>%
+    dplyr::transmute(
+      cohort_definition_id = .data$cohort_definition_id,
+      number_records = .data$n_records,
+      number_subjects = .data$n_subjects,
+      reason_id = 1L + .data$reason_id,
+      reason = "Cohort records collapsed",
+      excluded_records = .data$excluded_records,
+      excluded_subjects = .data$excluded_subjects
+    )
+
+  attrition <- dplyr::bind_rows(attrition, newAttritionRow) %>%
+    dplyr::arrange(.data$cohort_definition_id, .data$reason_id)
+
   # upload attrition table to database
   DBI::dbWriteTable(con,
                     name = .inSchema(schema, paste0(cohortStem, "_attrition"), dbms = dbms(con)),
@@ -949,23 +716,3 @@ caprConceptToDataframe <- function(x) {
   )
 }
 
-
-#' Add attrition reason to a cohort_table object
-#'
-#' Update the cohort attrition table with new counts and a reason for attrition.
-#'
-#' @param cohort A generated cohort set
-#' @param reason The reason for attrition as a character string
-#' @param cohortId Cohort definition id of the cohort you want to update the
-#' attrition
-#'
-#' @return The cohort object with the attributes created or updated.
-#'
-#' `r lifecycle::badge("deprecated")`
-#'
-#' @export
-record_cohort_attrition <- function(cohort, reason, cohortId = NULL) {
-  lifecycle::deprecate_soft("1.7.0", "record_cohort_attrition()", "recordCohortAttrition()")
-  omopgenerics::recordCohortAttrition(cohort = cohort, reason = reason, cohortId = cohortId)
-}
-
